<#macro registrationLayout bodyClass="" displayInfo=false displayMessage=true displayRequiredFields=false displayWide=false showAnotherWayIfPresent=true>
<!doctype html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

  <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/css/bootstrap.min.css" integrity="sha384-MCw98/SFnGE8fJT3GXwEOngsV7Zt27NXFoaoApmYm81iuXoPkFOJwJ8ERdknLPMO" crossorigin="anonymous">

  <title>${properties.titleTag}</title>
  <link rel="icon" href="${properties.favicon}" />
  <#if properties.styles?has_content>
    <#list properties.styles?split(' ') as style>
      <link href="${url.resourcesPath}/${style}" rel="stylesheet" />
    </#list>
  </#if>

  <style>
  </style>
</head>

<body style="${properties.bodyStyle!}">
  <header>
    <div class="container-fluid">
      <div class="row py-3">
        <div class="col">
          <a href="${client.getBaseUrl()}">
            <#if properties.logoSrc?has_content>
              <img class="img-fluid float-left" alt="${properties.logoAlt}" src="${properties.logoSrc}" style="${properties.logoStyle}">
            <#else>
              <h1>${client.getName()?capitalize?keep_before('.')}</h1>
            </#if>
          </a>
        </div>
				<#if properties.infrastructureLogo?has_content && properties.infrastructureLogo='yes'>
          <div class="col">
            <a target="_blank" href="http://www.d4science.org">
              <img class="img-fluid float-right" alt="D4Science Infrastructure" src="https://sobigdata.d4science.org/sobigdata-site-theme/images/custom/PoweredByD4Science.png">
            </a>
          </div>
				</#if>
      </div>
    </div>    
    <nav class="navbar navbar-expand-lg navbar-light" style="${properties.navbarStyle}">
      <div>
        <#if properties.navbarActive?has_content>
        <style>li.active { ${properties.navbarActive} }</style>
        </#if>
        <ul class="navbar-nav">
          <li class="nav-item active">${msg("doLogIn")}</li>
        </ul>
      </div>
    </nav>
  </header>

  <!-- Realm data
	<div id="kc-header" class="${properties.kcHeaderClass!}">
    <div id="kc-header-wrapper" class="${properties.kcHeaderWrapperClass!}">${kcSanitize(msg("loginTitleHtml",(realm.displayNameHtml!'')))?no_esc}</div>
  </div>
	-->
  
  <div id="content" style="${properties.contentStyle!}">
  <div class="container">

		<div class="row pt-3 pb-2">
			<div class="col">
				<h3><#nested "header"></h3>
			</div>
		</div>

    <#-- App-initiated actions should not see warning messages about the need to complete the action -->
    <#-- during login.                                                                               -->
    <#if displayMessage && message?has_content && (message.type != 'warning' || !isAppInitiatedAction??)>
      <div class="alert alert-${message.type}">
        <#if message.type = 'success'><span class="${properties.kcFeedbackSuccessIcon!}"></span></#if>
        <#if message.type = 'warning'><span class="${properties.kcFeedbackWarningIcon!}"></span></#if>
        <#if message.type = 'error'><span class="${properties.kcFeedbackErrorIcon!}"></span></#if>
        <#if message.type = 'info'><span class="${properties.kcFeedbackInfoIcon!}"></span></#if>
        <span class="kc-feedback-text">${kcSanitize(message.summary)?no_esc}</span>
      </div>
    </#if>
    
    <div class="row pb-5">
      <div class="col">
        <#nested "form">

        <#if displayInfo>
          <div id="kc-info" class="${properties.kcSignUpClass!}">
            <div id="kc-info-wrapper" class="${properties.kcInfoAreaWrapperClass!}">
              <#nested "info">
            </div>
          </div>
        </#if>
      </div>
    </div>
 
  </div>
  </div>

  <footer class="footer container-fluid" style="${properties.footerStyle}">
    <div class="row pb-3">
      <div class="col-12 pt-3">
        <a href="${properties.linkTerms}">Terms of Use</a> | 
        <a href="${properties.linkCookies}">Cookies Policy</a> | 
        <a href="${properties.linkPrivacy}" target="_blank">Privacy Policy</a> | 
        <#if properties.linkProject?has_content><a href="${properties.linkProject}" target="_blank">${properties.descrProject}</a></#if>
      </div>
      <div class="col-12 text-right">
        <a href="http://ec.europa.eu/programmes/horizon2020/" target="_blank">
        <#if properties.ECLogoSrc?has_content>
          <img class="float-right" alt="${properties.ECLogoAlt}" src="${properties.ECLogoSrc}" style="${properties.ECLogoStyle}">
        <#else>
          ${properties.ECLogoAlt}
        </#if>
        </a>
      </div>
      <#if properties.footerRow1?has_content><div class="col-12 text-right">${properties.footerRow1}</div></#if>
      <#if properties.footerRow2?has_content><div class="col-12 text-right">${properties.footerRow2}</div></#if>
    </div>
  </footer>

  <script src="https://code.jquery.com/jquery-3.3.1.slim.min.js" integrity="sha384-q8i/X+965DzO0rT7abK41JStQIAqVgRVzpbzo5smXKp4YfRvH+8abtTE1Pi6jizo"  crossorigin="anonymous"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js" integrity="sha384-ZMP7rVo3mIykV+2+9J3UJ46jBk0WLaUAdn689aCwoqbBJiSnjAK/l8WvCWPIPm49" crossorigin="anonymous"></script>
  <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js" integrity="sha384-ChfqqxuZUCnJSK3+MXmPNIyE6ZbWh2IMqE241rYiqJxyMiZ6OW/JmZQ5stwEULTy" crossorigin="anonymous"></script>

</body>
</html>
</#macro>